cordova.define("com.progon.promegon.cordova.push.Promegon.PushPlugin", function(require, exports, module) { var exec = require("cordova/exec");

/**
 * This is a global variable called push exposed by cordova
 * @status Stable
 * @constructs Push
 */
function Push(){
    this.FetchResult = {
        NewData: 0,
        NoData: 1,
        Failed: 2
    }
}

/**
    Registers the device with the APNS (iOS) or GCM (Android) and the Promegon Push server.
    @param {Function} onNotification - callback to be executed if a message arrives
    @param {Function} successCallback - callback to be executed when register is succesful
    @param {Function} [errorCallback] - callback to be executed if the request results in error
    @param {Object} options - A configuration for the Promegon Push server, so that it can register this device. If an object or array containing objects is used, the objects can have the following properties:
    @param {String} [options.senderId] - android specific - the id representing the Google project ID
    @param {String} options.appId - the id representing the mobile application
    @param {String} options.appSecret - the secret for the mobile application
    @param {String} options.subdomain - the name of the account subdomain e.g. mysubdomain
    @param {String} [options.alias] - Application specific alias to identify users with the system. Common use case would be an email address or a username.
    @param {Object} [options.ios] - Holder of the ios specific values appId and appSecret
    @param {String} [options.ios.appId] - the id representing the mobile application for iOS
    @param {String} [options.ios.appSecret] - the secret for the mobile application for iOS
    @param {Object} [options.android] - Holder of the android specific values appId and appSecret
    @param {String} [options.android.appId] - the id representing the mobile application for android
    @param {String} [options.android.appSecret] - the secret for the mobile application for android
    @returns {void}
    @example

    var pushConfig = {
        subdomain: "<Account subdomain e.g mysubdmain>",
        senderID: "<senderID e.g Google Project ID>",
        appId: "<appId e.g. 1234456-234320>",
        appSecret: "<appSecret e.g. 1234456-234320>"
        alias: "<alias e.g. a username or an email address optional>",
    }

    push.register(onNotification, errorHandler, pushConfig);

    @example
    //combined android and ios configuration
    var pushConfig = {
        subdomain: "<Account subdomain e.g mysubdmain>",
        alias: "<alias e.g. a username or an email address optional>",
        android: {
          senderID: "<senderID e.g Google Project ID>",
          appId: "<appId e.g. 1234456-234320>",
          appSecret: "<appSecret e.g. 1234456-234320>"
        },
        ios: {
          appId: "<appId e.g. 1234456-234320>",
          appSecret: "<appSecret e.g. 1234456-234320>"
        }
    };

    push.register(onNotification, errorHandler, pushConfig);
*/
Push.prototype.register = function (onNotification, successCallback, errorCallback, options) {
    this.successCallback = successCallback;

    if (errorCallback == null) {
        errorCallback = function () {
        }
    }

    if (typeof onNotification != "function") {
        console.log("Push.register failure: onNotification callback parameter must be a function");
        return;
    }

    cordova.exec(onNotification, errorCallback, "PushPlugin", "register", [options]);
};

/**
    Unregisters the device with the APNS (iOS) or GCM (Android) and the Promegon Push server.
    @status Stable
    @param {Function} success - callback to be executed if the request results in success
    @param {Function} [error] - callback to be executed if the request results in error
    @returns {void}
    @example

    push.unregister(successHandler, errorHandler);
*/
Push.prototype.unregister = function (successCallback, errorCallback) {
    if (errorCallback == null) {
        errorCallback = function () {
        }
    }

    if (typeof successCallback != "function") {
        console.log("Push.unregister failure: success callback parameter must be a function");
        return;
    }

    cordova.exec(successCallback, errorCallback, "PushPlugin", "unregister", []);
};


/**
    Call this to set the application icon badge -- ios specific
    @status Stable
    @param {Function} success - callback to be executed if the request results in success
    @param {String|Number} [badge] - the badge number to set on the application icon
    @returns {void}
    @example

    push.setApplicationIconBadgeNumber(successHandler, errorHandler);
*/
Push.prototype.setApplicationIconBadgeNumber = function (successCallback, badge) {
    if (typeof successCallback != "function") {
        console.log("Push.setApplicationIconBadgeNumber failure: success callback parameter must be a function");
        return;
    }

    cordova.exec(successCallback, successCallback, "PushPlugin", "setApplicationIconBadgeNumber", [
        {badge: badge}
    ]);
};

/**
 * Call this function to tell the OS if there was data or not so it can schedule the next fetch operation
 * @param {int} dataType - one of the BackgroundFetchResults or 0 new data 1 no data or 2 failed
 * @returns {void}
 */
Push.prototype.setContentAvailable = function(dataType) {
    return exec(null, null, "PushPlugin", "setContentAvailable", [{type: dataType}]);
};

var push = new Push();
if (Object.freeze) {
    Object.freeze(push.FetchResult);
}

module.exports = push;

});
